{% load i18n admin_urls static admin_modify ddm_tags %}

<div class="sq-nav-lvl-1">
  <div class="sq-nav-card-top">Questionnaires</div>
  <a href="{% url 'questionnaire-list' %}">
    <div class="sq-nav-card {% if request.resolver_match.url_name == 'questionnaire-list' %}sq-nav-card-active{% endif %}">List</div>
  </a>
</div>
