{% extends 'ddm/project_admin/generic/page_with_form.html' %}

{% block page_title %}Delete Instruction{% endblock %}

{% block main_heading %}Delete Instruction Page{% endblock %}

{% block main_top %}
<p>You are about to delete the following instruction page:</p>
<div>
  <table class="table">
    <tr>
      {% if object.blueprint %}
      <td style="width: 16%">Related blueprint:</td>
      <td>{{ object.blueprint }}</td>
      {% elif object.zip_blueprint.name %}
      <td>Zipped Blueprint:</td>
      <td>{{ object.zip_blueprint.name }}</td>
      {% endif %}
    </tr>
    <tr>
      <td>Index:</td>
      <td>{{ object.index }}</td>
    </tr>
    <tr>
      <td>Text:</td>
      <td>{{ object.text | safe }}</td>
    </tr>
  </table>
</div>
{% endblock %}


{% block main_form%}
<form method='post'>
  {% csrf_token %}
  <p>Are you sure you want to delete this instruction page? <b>This action cannot be reversed.</b></p>
  <input class="btn-a btn-danger" type="submit" value="Delete instruction page">
</form>
{% endblock %}


{% block breadcrumbs %}
Back to:
<a href="{% url 'project-list' %}">Projects</a> /
<a href="{% url 'project-detail' project_pk %}">Project Cockpit</a> /
<a href="{% url 'blueprint-list' project_pk %}">Donation Blueprints</a> /
<a href="{% url 'instruction-overview' project_pk blueprint.get_slug blueprint.pk %}">Instruction Overview</a>
{% endblock %}
