{% load static i18n sekizai_tags %}
<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <title>DDL: {% block page_title %}Title{% endblock %}</title>

  <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet"
        integrity="sha384-1BmE4kWBq78iYhFldvKuhfTAU6auU8tT94WrHftjDbrCEXSU1oBoqyl2QvZ6jIW3" crossorigin="anonymous">
  <link href='{% static "ddm/css/research-interface-base.css" %}' rel='stylesheet'>
  <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.8.1/font/bootstrap-icons.css">
  <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.0.2/dist/js/bootstrap.bundle.min.js" integrity="sha384-MrcW6ZMFYlzcLA8Nl+NtUVF0sA7MsXsP1UyJoMp4YLEuNSfAP+JcXn/tWtIaxVXM" crossorigin="anonymous"></script>
  {% block extrahead %}{% endblock %}
</head>

<body>

<div class="container mt-5">
  <h1>{% block main_heading %}{% endblock %}</h1>

  <div>
    {% block main_body %}{% endblock %}
  </div>

</div>

<div class="container mt-4 mb-4 fs-6 fw-light">
  <hr>
  {% block breadcrumbs %}
  {% endblock %}
</div>

</body>

</html>
