{% load static i18n sekizai_tags %}
<!DOCTYPE html>
<html lang="{{ LANGUAGE_CODE }}">
<head>
  <meta charset="utf-8">
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <!-- The above 3 meta tags *must* come first in the head; any other head content must come *after* these tags -->
  <title>{% block title %} - {{ request.site.name }}{% endblock title %}</title>

  <!-- Bootstrap -->
  <link href="{% static 'ddm/css/bootstrap4/bootstrap.min.css' %}" rel="stylesheet">
  <link href="{% static 'ddm/css/questionnaire.css' %}" rel="stylesheet">

  {% block extra_head %}{% endblock %}

  {% render_block "css" %}

  {{ ALDRYN_SNAKE.render_head }}

</head>
<body>

<div class="container py-3 surquest-questionnaire-header">
  {% block questionnaire-header %}
    <div>
      <img style="float: right" src="{% static 'ddm/img/uzh_logo.svg' %}">
    </div>
    <div>
      <img src="{% static 'ddm/img/ikmz_logo.svg' %}">
    </div>
  {% endblock %}
</div>

<div class="container py-3">
  {% block content %}{% endblock %}
</div>

<!-- jQuery (necessary for Bootstrap's JavaScript plugins) -->
<script src="https://ajax.googleapis.com/ajax/libs/jquery/3.4.1/jquery.min.js"></script>
<!-- Include all compiled plugins (below), or include individual files as needed -->
<script src="{% static 'ddm/js/bootstrap4/bootstrap.bundle.min.js' %}"></script>

{% block extra_js %}{% endblock %}

{% render_block "js" %}

</body>
</html>
