{% extends "ddm/public/base.html" %}
{% load render_bundle from webpack_loader %}

{% block content %}
<div class="container">
  <form id="uploader-form" method="POST" enctype="multipart/form-data">
    {% csrf_token %}
    <div id="uapp"
         class="container text-black"
         data-uploadconfig='{{ ul_configs }}'
         data-actionurl='{{ request.build_absolute_uri }}'>
      <uapp></uapp>
    </div>
    {% render_bundle 'vue_uploader' %}
  </form>
</div>
{% endblock content %}
