{% load static i18n sekizai_tags %}
<!DOCTYPE html>
<html>
<head>
  <meta charset="utf-8">
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <meta name="viewport" content="width=device-width, initial-scale=1">

  <title>{% block title %} - {{ request.site.name }}{% endblock title %}</title>

  <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet"
        integrity="sha384-1BmE4kWBq78iYhFldvKuhfTAU6auU8tT94WrHftjDbrCEXSU1oBoqyl2QvZ6jIW3" crossorigin="anonymous">
  <link href='{% static "ddm/css/public-base.css" %}' rel='stylesheet'>

  {% block extrahead %}{% endblock extrahead %}

</head>
<body>

<div class="container public-header">
  {% block public-header %}
  <div class="row align-items-center h-100">
    <div class="col h-100">
      <img class="h-100" src="{% static 'ddm/img/uzh_logo.svg' %}">
    </div>
    <div class="col">
      <img class="w-50 h-100 float-end" src="{% static 'ddm/img/ikmz_logo.svg' %}">
    </div>
  </div>
  {% endblock public-header %}
</div>

<div class="container public-main">
  <div class="row">
    {% block content %}{% endblock %}
  </div>
</div>

<div class="container public-footer">
  <!-- Footer -->
  {% block public-footer %}
  <div class="row justify-content-md-center">
    <div class="col-md-auto text-center">
      <a href="#" class="text-orange">Kontakt</a>
    </div>
    <div class="col-md-auto text-center">
      <a href="#" class="text-orange">Was passiert mit meinen Daten?</a>
    </div>
  </div>
  {% endblock public-footer %}
</div>

</div>

<script src="https://ajax.googleapis.com/ajax/libs/jquery/3.4.1/jquery.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"
        integrity="sha384-ka7Sk0Gln4gmtz2MlQnikT1wXgYsOg+OMhuP+IlRH9sENBO0LRn5q+8nbTov4+1p"
        crossorigin="anonymous"></script>

</body>
</html>
