{% extends "ddm/admin/forms/base_form.html" %}
{% load i18n admin_urls static admin_modify ddm_tags %}

{% block form_content %}

  <div class="sq-hidden-form">{{ form.as_p }}</div>
  {% include "ddm/admin/forms/inline_form.html" %}

{% endblock %}


{% block form_submit %}

  <div class="sq-form-control">
    <input class="sq-btn sq-btn-main" type="submit" value="Save">

    {% if drop_menu_content %}
      <div class="sq-dropup float-right">

        <button id="dropup-button-page" type="button" class="sq-btn sq-dropup-button" onclick="changeDropup('dropup-button-page')" data-toggle="dropdown">
          Add Trigger&nbsp;&nbsp;&nbsp;<span>&#9656;</span>
        </button>

        <div class="sq-dropup-content">
          {% for type in drop_menu_content %}
            <a class="sq-dropup-item" href="{% url type.view_name questionnaire.id %}">{{ type.label }}</a>
          {% endfor %}
        </div>

      </div>
    {% endif %}

  </div>

{% endblock %}
