{% extends "ddm/admin/forms/base_form.html" %}
{% load i18n admin_urls static admin_modify ddm_tags %}

{% block side_nav %}
  {% include 'ddm/admin/navigation/side_navigation/level_1_questionnaires.html' %}
  {% include 'ddm/admin/navigation/side_navigation/level_2_questionnaire.html' %}
{% endblock side_nav %}

{% block page_title %}
  Triggers
{% endblock page_title %}

{% block page_subtitle %}
  {{ questionnaire.name }}
{% endblock page_subtitle %}

{% block form_submit %}
  {{ block.super }}
  {% include 'ddm/admin/controls/button_add_trigger.html' %}
{% endblock form_submit %}
