{% extends "ddm/public/base.html" %}
{% load static %}
{% load render_bundle from webpack_loader %}

{% block extrahead %}
<link href="{% static 'ddm/css/questionnaire.css' %}" rel="stylesheet">
{% endblock extrahead %}

{% block content %}
<div>
  <form method="POST">
    {% csrf_token %}
    <div id="qapp"
         data-qconfig='{{ q_config }}'
         data-actionurl='{{ request.build_absolute_uri }}'
         class="text-black"
    >
      <qapp></qapp>
    </div>
  </form>
  {% render_bundle 'vue_questionnaire' %}
</div>
{% endblock content %}
