{% extends 'ddm/project_admin/generic/page_with_form.html' %}

{% block page_title %}Delete Project{% endblock %}

{% block main_heading %}Delete "{{ object.name }}"{% endblock %}

{% block main_form %}
<form method='post'>
  {% csrf_token %}
  <p>You are about to delete the following project:</p>
  <div>
    <table>
      <tr>
        <td>Name:</td>
        <td>{{ object.name }}</td>
      </tr>
      <tr>
        <td>Slug:</td>
        <td>{{ object.slug }}</td>
      </tr>
      <tr>
        <td>Intro Text:</td>
        <td>{{ object.intro_text }}</td>
      </tr>
      <tr>
        <td>Outro Text:</td>
        <td>{{ object.outro_text }}</td>
      </tr>
    </table>
  </div>
  <p>All collected data associated with this project will also be deleted. <b>This action cannot be reversed.</b></p>
  <p>Are you sure you want to delete this project?</p>
  <input class="btn-a btn-danger" type="submit" value="Delete project">
</form>
{% endblock %}

{% block breadcrumbs %}
Back to:
<a href="{% url 'project-list' %}">Projects</a> /
<a href="{% url 'project-detail' object.pk %}">Project Cockpit</a>
{% endblock %}
