.carousel[data-v-052c08e8]{min-height:250px}.carousel-control-next[data-v-052c08e8],.carousel-control-prev[data-v-052c08e8]{width:auto}.carousel-inner[data-v-052c08e8]{padding-left:42px;padding-right:42px}.carousel-item[data-v-052c08e8]{transition:transform .3s ease,opacity .3s ease-out}.accordion-button[data-v-ff5c9480]:focus{outline:none;box-shadow:none}.accordion-button[data-v-ff5c9480]:not(.collapsed){background-color:#fff;color:#000;border-bottom:none;box-shadow:none}.accordion-button[data-v-ff5c9480]{background-color:#efefef;color:#000;border-bottom:none}.accordion-button[data-v-ff5c9480]:not(.collapsed):after{background-image:url("data:image/svg+xml;charset=utf-8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23212529'%3E%3Cpath fill-rule='evenodd' d='M1.646 4.646a.5.5 0 01.708 0L8 10.293l5.646-5.647a.5.5 0 01.708.708l-6 6a.5.5 0 01-.708 0l-6-6a.5.5 0 010-.708z'/%3E%3C/svg%3E")}.accordion-button[data-v-ff5c9480],.accordion-item[data-v-ff5c9480],.accordion-item[data-v-ff5c9480]:first-of-type{border-radius:0!important}.form-check-input[data-v-ff5c9480],.form-check-label[data-v-ff5c9480]{cursor:pointer}.form-check-input[data-v-ff5c9480]{margin-top:0}.ul-success[data-v-ff5c9480]{background-color:rgba(85,255,85,.09019607843137255)}.fb-modal[data-v-ff5c9480]{max-width:80%;height:80%}.modal-body-data[data-v-ff5c9480]{overflow:auto;max-height:400px}#uapp{font-family:Avenir,Helvetica,Arial,sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;color:#2c3e50}